import { ConstantsUtil } from '@web3modal/scaffold-utils';
import { PresetsUtil } from '@web3modal/scaffold-utils';
export const Web3HelpersUtil = {
    getCaipDefaultChain(chain) {
        if (!chain) {
            return undefined;
        }
        return {
            id: `${ConstantsUtil.EIP155}:${chain.chainId}`,
            name: chain.chainName,
            imageId: PresetsUtil.EIP155NetworkImageIds[chain.chainId]
        };
    },
    hexStringToNumber(value) {
        const string = value.startsWith('0x') ? value.slice(2) : value;
        const number = parseInt(string, 16);
        return number;
    },
    numberToHexString(value) {
        return `0x${value.toString(16)}`;
    },
    async getUserInfo(provider) {
        const [address, chainId] = await Promise.all([
            Web3HelpersUtil.getAddress(provider),
            Web3HelpersUtil.getChainId(provider)
        ]);
        return { chainId, address };
    },
    async getChainId(provider) {
        const chainId = await provider.request({ method: 'eth_chainId' });
        return Number(chainId);
    },
    async getAddress(provider) {
        const [address] = await provider.request({ method: 'eth_accounts' });
        return address;
    },
    async addEthereumChain(provider, chain) {
        await provider.request({
            method: 'wallet_addEthereumChain',
            params: [
                {
                    chainId: Web3HelpersUtil.numberToHexString(chain.chainId),
                    rpcUrls: chain.rpcUrls,
                    chainName: chain.chainName,
                    nativeCurrency: {
                        name: chain.nativeCurrency.name,
                        decimals: 18,
                        symbol: chain.nativeCurrency.symbol
                    },
                    blockExplorerUrls: chain.blockExplorerUrls,
                    iconUrls: [PresetsUtil.EIP155NetworkImageIds[chain.chainId]]
                }
            ]
        });
    }
};
//# sourceMappingURL=Web3HelpersUtil.js.map